<?php
namespace Elementor;

class Webnus_Element_Widgets_Subscribe extends \Elementor\Widget_Base {

	/**
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {

		return 'subscribe';

	}

	/**
	 * Retrieve widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {

		return esc_html__( 'Webnus Subscribe', 'deep' );

	}

	/**
	 * Retrieve widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {

		return 'eicon-mail';

	}


	/**
	 * Set widget category.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget category.
	 */
	public function get_categories() {

		return [ 'webnus' ];

	}

	/**
	 * widget styles.
	 *
	 * @since 4.2.0
	 * @access public
	 *
	 */
	public function get_style_depends() {

		return [ 'wn-deep-subscribe' ];

	}

	/**
	 * Register widget controls.
	 *
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		// Content Tab
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'General', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
		);

		$this->add_control(
			'type',
			[
				'label' =>  esc_html__( "Type", 'deep' ),
				'type'	=> \Elementor\Controls_Manager::SELECT,
				'description' 	=>  esc_html__( "Select style type", 'deep'),
				'options'	=>	[
					"boxed" =>  esc_html__( "Boxed", 'deep'),
					"bar1" =>  esc_html__( "Bar", 'deep'),
					"flat" =>  esc_html__( "Flat", 'deep'),
					"wish" =>  esc_html__( "Wish", 'deep') ,
					"modern" =>  esc_html__( "Modern", 'deep') ,
					"bordered" =>  esc_html__( "Bordered", 'deep'),
					"rounded" =>  esc_html__( "Rounded", 'deep'),
					"full"	=>  esc_html__( "Full", 'deep' ),
				],
				'default'			=> 'boxed',
			]
		);

		$this->add_control(
			'box_title',
			[
				'label' =>  esc_html__( "Title", 'deep' ),
				'type'	=> \Elementor\Controls_Manager::TEXT,
				'description'	=>  esc_html__( "Subscribe title", 'deep'),
				'condition'		=> [
					'type'	=>	[
						'boxed',
						'bar1',
						'flat' ,
						'bordered',
					]
				]
			]
		);

		$this->add_control(
			'input_text',
			[
				'label' =>  esc_html__( 'input text', 'deep' ),
				'type'	=> \Elementor\Controls_Manager::TEXT,
				'description'	=>  esc_html__( 'input box text', 'deep'),
				'placeholder'	=>  esc_html__( 'YOUR E-MAIL', 'deep' ),
			]
		);

		$this->add_control(
			'box_text',
			[
				'label' =>  esc_html__( "Subscribe Text", 'deep' ),
				'type'	=> \Elementor\Controls_Manager::TEXT,
				'description'	=>  esc_html__( "Subscribe content", 'deep'),
				'condition'		=> [
					'type'	=>	[
						'boxed',
						'bar1',
						'flat' ,
						'bordered',
					]
				]
			]
		);

		$this->add_control(
			'service',
			[
				'label' 			=>  esc_html__( "Email Service", 'deep' ),
				'type'				=> \Elementor\Controls_Manager::SELECT,
				'description'		=>  esc_html__( "FeedBurner or MailChimp", 'deep'),
				'options'			=> [
					'feedburner' => 'FeedBurner',
					'mailchimp'	 => 'MailChimp',
				],
				'default'			=> 'feedburner',
			]
		);

		$this->add_control(
			'feedburner_id',
			[
				'label' =>  esc_html__( "FeedBurner ID", 'deep' ),
				'type'	=> \Elementor\Controls_Manager::TEXT,
				'description'	=>  esc_html__( "FeedBurner ID", 'deep'),
				'condition'		=> [
					'service'	=>	[
						'feedburner'
					]
				]
			]
		);

		$this->add_control(
			'mailchimp_url',
			[
				'label' =>  esc_html__( "MailChimp URL", 'deep' ),
				'type'	=> \Elementor\Controls_Manager::TEXT,
				'description'	=>  esc_html__( "Mailchimp form action URL", 'deep'),
				'condition'		=> [
					'service'	=>	[
						'mailchimp'
					]
				]
			]
		);

    $this->end_controls_section();

		// Class & ID Tab
		$this->start_controls_section(
			'classid_section',
			[
				'label' => esc_html__( 'Class & ID', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
						]
		);

		$this->add_control(
			'shortcodeclass',
			[
				'label'	=>  esc_html__( 'Extra Class', 'deep' ),
				'type'	=> \Elementor\Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'shortcodeid',
			[
				'label'	=>  esc_html__( 'ID', 'deep' ),
				'type'	=> \Elementor\Controls_Manager::TEXT,
			]
		);

		$this->end_controls_section();

			// Style
			$this->start_controls_section(
				'section_title_style',
				[
					'label' => __( 'Title', 'deep' ),
					'tab' => Controls_Manager::TAB_STYLE,
					'condition'		=> [
						'type!'	=>	[
							'wish',
							'modern',
							'rounded' ,
							'full',
						]
					]
				]
			);
	
			$this->add_responsive_control(
				'title_text_align',
				[
					'label'     => __( 'Text align', 'deep' ),
					'type'      => \Elementor\Controls_Manager::CHOOSE,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'options'   => [
						'left'   => [
							'title' => __( 'Left', 'deep' ),
							'icon'  => 'fa fa-align-left',
						],
						'center' => [
							'title' => __( 'Center', 'deep' ),
							'icon'  => 'fa fa-align-center',
						],
						'right'  => [
							'title' => __( 'Right', 'deep' ),
							'icon'  => 'fa fa-align-right',
						],
					],				
					'toggle'    => true,
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'text-align: {{VALUE}}',
					],
				]
			);
	
			$this->add_responsive_control(
				'title_float',
				[
					'label'     => __( 'Float', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,		
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'right'      => __( 'Right', 'deep' ),
						'left'       => __( 'Left', 'deep' ),
						'unset' => __( 'Unset', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'float: {{VALUE}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
	
			$this->add_responsive_control(
				'title_display',
				[
					'label'     => __( 'Display', 'deep' ), 
					'devices' => [ 'desktop', 'tablet', 'mobile' ],	
					'type'      => \Elementor\Controls_Manager::SELECT,		
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'inherit'      => __( 'Inherit', 'deep' ),
						'inline'       => __( 'inline', 'deep' ),
						'inline-block' => __( 'inline block', 'deep' ),
						'block'        => __( 'block', 'deep' ),
						'none'         => __( 'none', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'display: {{VALUE}};',
					],
				]
			);
	
			$this->start_controls_tabs(
				'wn_title_style_name_tabs'
			);
	
			$this->start_controls_tab(
				'style_title_name_normal_tab',
				[
					'label' => __( 'Normal', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography',
					'label' 	=> __( 'Title Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} h3',
				]
			);
	
			$this->add_control(
				'title_color', 
				[
					'label' 		=> __( 'Title color', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::COLOR,
					'selectors' 	=> [
						'#wrap {{WRAPPER}} h3' => 'color: {{VALUE}}',
					],
				]
			);
			
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' => 'title_bg',
					'label' => __( 'Background', 'deep' ),
					'types' => [ 'classic' ],
					'selector' => '#wrap {{WRAPPER}} h3',
				]
			);
	
			$this->add_responsive_control(
				'title_opacity',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'opacity: {{SIZE}};',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'title_border',
					'label' => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} h3',
				]
			);
	
			$this->add_responsive_control(
				'title_border_radius', 
				[
					'label' 		=> __( 'Border Radius', 'deep' ), 
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ], 
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			
			$this->add_responsive_control(
				'title_padding', 
				[
					'label' 		=> __( 'Title padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'title_margin', 
				[
					'label' 		=> __( 'Title margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);		
	
			$this->end_controls_tab();
	
			$this->start_controls_tab(
				'style_title_hover_tab',
				[
					'label' => __( 'Hover', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography_hover',
					'label' 	=> __( 'Title Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} .wn-sb-hole:hover h3',
				]
			);
	
			$this->add_control(
				'title_color_hover', 
				[
					'label' 		=> __( 'Title color', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::COLOR,
					'selectors' 	=> [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover h3' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' => 'title_bg_hover',
					'label' => __( 'Background', 'deep' ),
					'types' => [ 'classic' ],
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole:hover h3',
				]
			);
	
			$this->add_responsive_control(
				'title_opacity_hover',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover h3' => 'opacity: {{SIZE}};',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'title_border_hover',
					'label' => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole:hover h3',
				]
			);
	
			$this->add_responsive_control(
				'title_border_radius_hover', 
				[
					'label' 		=> __( 'Border Radius', 'deep' ), 
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover h3' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'title_padding_hover', 
				[
					'label' 		=> __( 'Title padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'title_margin_hover', 
				[
					'label' 		=> __( 'Title margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);	
	
			$this->end_controls_tab();
			$this->end_controls_tabs();
	
			$this->add_control(
				'title_transition',
				[
					'label' => __( 'Transition', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'transition: all {{SIZE}}s ease;',
					],
					'separator' => 'before',
				]
			);
			
			$this->add_responsive_control(
				'subs_title_position',
				[
					'label' => __( 'Position', 'deep' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => [
						''  => __( 'Default', 'deep' ),
						'relative'  => __( 'Relative', 'deep' ),
						'absolute' => __( 'Absolute', 'deep' ),
						'fixed' => __( 'Fixed', 'deep' ),
						'static' => __( 'Static', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'position: {{VALUE}}',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
			
			$this->add_responsive_control(
				'subs_title_pos_top',
				[
					'label' => __( 'Top', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'top: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'subs_title_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'subs_title_pos_right',
				[
					'label' => __( 'Right', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'right: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'subs_title_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'subs_title_pos_bottom',
				[
					'label' => __( 'Bottom', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'bottom: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'subs_title_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'subs_title_pos_left',
				[
					'label' => __( 'Left', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} h3' => 'left: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'subs_title_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			
			$this->end_controls_section();
	
			// Sbuscribe Text
			$this->start_controls_section(
				'section_subscribe_text_style',
				[
					'label' => __( 'Subscribe Text', 'deep' ),
					'tab' => Controls_Manager::TAB_STYLE,
					'condition'		=> [
						'type!'	=>	[
							'wish',
							'modern',
							'rounded' ,
							'full',
						]
					]
				]
			);
	
			$this->add_responsive_control(
				'subscribe_text_align',
				[
					'label'     => __( 'Text align', 'deep' ),
					'type'      => \Elementor\Controls_Manager::CHOOSE,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'options'   => [
						'left'   => [
							'title' => __( 'Left', 'deep' ),
							'icon'  => 'fa fa-align-left',
						],
						'center' => [
							'title' => __( 'Center', 'deep' ),
							'icon'  => 'fa fa-align-center',
						],
						'right'  => [
							'title' => __( 'Right', 'deep' ),
							'icon'  => 'fa fa-align-right',
						],
					],				
					'toggle'    => true,
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text' => 'text-align: {{VALUE}}',
					],
				]
			);
	
			$this->add_responsive_control(
				'subscribe_text_float',
				[
					'label'     => __( 'Float', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,		
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'right'      => __( 'Right', 'deep' ),
						'left'       => __( 'Left', 'deep' ),
						'unset' => __( 'Unset', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text' => 'float: {{VALUE}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
	
			$this->add_responsive_control(
				'subscribe_text_display',
				[
					'label'     => __( 'Display', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,	
					'devices' => [ 'desktop', 'tablet', 'mobile' ],	
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'inherit'      => __( 'Inherit', 'deep' ),
						'inline'       => __( 'inline', 'deep' ),
						'inline-block' => __( 'inline block', 'deep' ),
						'block'        => __( 'block', 'deep' ),
						'none'         => __( 'none', 'deep' ),
					],	
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text p' => 'display: {{VALUE}};',
					],
				]
			);
	
			$this->start_controls_tabs(
				'wn_team_style_name_tabs'
			);
	
			$this->start_controls_tab(
				'style_team_name_normal_tab',
				[
					'label' => __( 'Normal', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'subscribe_text_typography',
					'label' 	=> __( 'Text Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} .subscribe-box-text p',
				]
			);
			
			$this->add_control(
				'subscribe_text_color', 
				[
					'label' 		=> __( 'Text color', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::COLOR,
					'selectors' 	=> [
						'#wrap {{WRAPPER}} .subscribe-box-text p' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' => 'subscribe_text_bg',
					'label' => __( 'Background', 'deep' ),
					'types' => [ 'classic' ],
					'selector' => '#wrap {{WRAPPER}} .subscribe-box-text p',
				]
			);
		
			$this->add_responsive_control(
				'subscribe_text_opacity',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],	
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text p' => 'opacity: {{SIZE}};',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'subscribe_text_border',
					'label' => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .subscribe-box-text p',
				]
			);
	
			$this->add_responsive_control(
				'subscribe_text_border_radius', 
				[
					'label' 		=> __( 'Border Radius', 'deep' ), 
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],	 
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text p' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'subscribe_text_padding', 
				[
					'label' 		=> __( 'Text padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],	
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			$this->add_responsive_control(
				'subscribe_text_margin', 
				[
					'label' 		=> __( 'Text margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],	
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);	
	
			$this->end_controls_tab();
	
			$this->start_controls_tab(
				'style_subscribe_text_hover_tab',
				[
					'label' => __( 'Hover', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'subscribe_typography_hover',
					'label' 	=> __( 'Text Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} .wn-sb-hole:hover .subscribe-box-text p',
				]
			);
	
			$this->add_control(
				'subscribe_text_color_hover', 
				[
					'label' 		=> __( 'Text color', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::COLOR,
					'selectors' 	=> [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover .subscribe-box-text p' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' => 'subscribe_text_bg_hover',
					'label' => __( 'Background', 'deep' ),
					'types' => [ 'classic' ],
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole:hover .subscribe-box-text p',
				]
			);
	
			$this->add_responsive_control(
				'subscribe_text_opacity_hover',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover .subscribe-box-text p' => 'opacity: {{SIZE}};',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'subscribe_text_hover',
					'label' => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole:hover .subscribe-box-text p',
				]
			);
	
			$this->add_responsive_control(
				'subscribe_text_radius_hover', 
				[
					'label' 		=> __( 'Border Radius', 'deep' ), 
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ], 
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover .subscribe-box-text p' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'subscribe_text_padding_hover', 
				[
					'label' 		=> __( 'Text padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover .subscribe-box-text p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'subscribe_text_margin_hover', 
				[
					'label' 		=> __( 'Text margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover .subscribe-box-text p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);	
	
			$this->end_controls_tab();
			$this->end_controls_tabs();
	
			$this->add_control(
				'subs_text_transition',
				[
					'label' => __( 'Transition', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text' => 'transition: all {{SIZE}}s ease;',
					],
					'separator' => 'before',
				]
			);
			
			$this->add_responsive_control(
				'subs_text_position',
				[
					'label' => __( 'Position', 'deep' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => [
						''  => __( 'Default', 'deep' ),
						'relative'  => __( 'Relative', 'deep' ),
						'absolute' => __( 'Absolute', 'deep' ),
						'fixed' => __( 'Fixed', 'deep' ),
						'static' => __( 'Static', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text p' => 'position: {{VALUE}}',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
			
			$this->add_responsive_control(
				'subs_text_pos_top',
				[
					'label' => __( 'Top', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text p' => 'top: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'subs_text_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'subs_text_pos_right',
				[
					'label' => __( 'Right', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text p' => 'right: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'subs_text_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'subs_text_pos_bottom',
				[
					'label' => __( 'Bottom', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text p' => 'bottom: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'subs_text_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'subs_text_pos_left',
				[
					'label' => __( 'Left', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .subscribe-box-text p' => 'left: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'subs_text_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->end_controls_section();	
			
			$this->start_controls_section(
				'section_input_style',
				[
					'label' => __( 'Input Style', 'deep' ),
					'tab' => Controls_Manager::TAB_STYLE,
				]
			);
	
			$this->add_responsive_control(
				'input_text_align',
				[
					'label'     => __( 'Alignment', 'deep' ),
					'type'      => \Elementor\Controls_Manager::CHOOSE,
					'options'   => [
						'left'   => [
							'title' => __( 'Left', 'deep' ),
							'icon'  => 'fa fa-align-left',
						],
						'center' => [
							'title' => __( 'Center', 'deep' ),
							'icon'  => 'fa fa-align-center',
						],
						'right'  => [
							'title' => __( 'Right', 'deep' ),
							'icon'  => 'fa fa-align-right',
						],
					],
					'default'   => 'left',
					'toggle'    => true,
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'text-align: {{VALUE}}',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
	
			$this->add_responsive_control(
				'input_float',
				[
					'label'     => __( 'Float', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,		
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'right'      => __( 'Right', 'deep' ),
						'left'       => __( 'Left', 'deep' ),
						'unset' => __( 'Unset', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'float: {{VALUE}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
	
			$this->add_responsive_control(
				'input_display',
				[
					'label'     => __( 'Display', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,	
					'devices' => [ 'desktop', 'tablet', 'mobile' ],	
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'inherit'      => __( 'Inherit', 'deep' ),
						'inline'       => __( 'inline', 'deep' ),
						'inline-block' => __( 'inline block', 'deep' ),
						'block'        => __( 'block', 'deep' ),
						'none'         => __( 'none', 'deep' ),
					],	
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'display: {{VALUE}};',
					],
				]
			);
	
			$this->start_controls_tabs(
				'wn_team_style_input_tabs'
			);
	
			$this->start_controls_tab(
				'style_input_normal_tab',
				[
					'label' => __( 'Normal', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'input_typography',
					'label' 	=> __( 'Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} .wn-sb-hole input',
				]
			);
			$this->add_control(
				'input_color', 
				[
					'label' 		=> __( 'Color', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::COLOR,
					'selectors' 	=> [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'place_input_typography',
					'label' 	=> __( 'Placeholder Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} .wn-sb-hole input::placeholder',
				]
			);
	
			$this->add_control(
				'input_placeholder_color', 
				[
					'label' 		=> __( 'Placeholder Color', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::COLOR,
					'selectors' 	=> [
						'#wrap {{WRAPPER}} .wn-sb-hole input::placeholder' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' => 'input_solid',
					'label' => __( 'Background', 'deep' ),
					'types' => [ 'classic' ],
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole input',
				]
			);
	
			$this->add_responsive_control(
				'input_opacity',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'opacity: {{SIZE}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
	
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'input_shadow',
						'label' => __( 'Box Shadow', 'deep' ),
						'selector' => '#wrap {{WRAPPER}} .wn-sb-hole input',
					]
			);
	
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'input_border',
					'label' => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole input',
				]
			);
	
			$this->add_responsive_control(
				'input_border_radius', 
				[
					'label' 		=> __( 'Border Radius', 'deep' ), 
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ], 
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'input_padding', 
				[
					'label' 		=> __( 'Padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			$this->add_responsive_control(
				'input_margin', 
				[
					'label' 		=> __( 'Margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);		
	
			$this->end_controls_tab();
	
			$this->start_controls_tab(
				'style_input_hover_tab',
				[
					'label' => __( 'Hover', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'input_typography_hover',
					'label' 	=> __( 'Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} .wn-sb-hole input:hover',
				]
			);
	
			$this->add_control(
				'input_color_hover', 
				[
					'label' 		=> __( 'Color', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::COLOR,
					'selectors' 	=> [
						'#wrap {{WRAPPER}} .wn-sb-hole input:hover' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'place_input_typography_hover',
					'label' 	=> __( 'Placeholder Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} .wn-sb-hole input:hover::placeholder',
				]
			);
	
			$this->add_control(
				'input_placeholder_color_hover', 
				[
					'label' 		=> __( 'Placeholder Color', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::COLOR,
					'selectors' 	=> [
						'#wrap {{WRAPPER}} .wn-sb-hole input:hover::placeholder' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' => 'input_solid_hover',
					'label' => __( 'Background', 'deep' ),
					'types' => [ 'classic' ],
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole input:hover',
				]
			);
	
			$this->add_responsive_control(
				'input_opacity_hover',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input:hover' => 'opacity: {{SIZE}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
	
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'input_shadow_hover',
						'label' => __( 'Box Shadow', 'deep' ),
						'selector' => '#wrap {{WRAPPER}} .wn-sb-hole input:hover',
					]
			);
	
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'input_border_hover',
					'label' => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole input:hover',
				]
			);
	
			$this->add_responsive_control(
				'input_border_radius_hover', 
				[
					'label' 		=> __( 'Border Radius', 'deep' ), 
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ], 
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'input_padding_hover', 
				[
					'label' 		=> __( 'Padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'input_margin_hover', 
				[
					'label' 		=> __( 'Margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);	
	
			$this->end_controls_tab();
	
			$this->start_controls_tab(
				'style_input_focus_tab',
				[
					'label' => __( 'Focus', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'input_typography_focus',
					'label' 	=> __( 'Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} .wn-sb-hole input:focus',
				]
			);
	
			$this->add_control(
				'input_color_focus', 
				[
					'label' 		=> __( 'Color', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::COLOR,
					'selectors' 	=> [
						'#wrap {{WRAPPER}} .wn-sb-hole input:focus' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' => 'input_bg_focus',
					'label' => __( 'Background', 'deep' ),
					'types' => [ 'classic' ],
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole input:focus',
				]
			);	
	
			$this->add_control(
				'input_opacity_focus',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input:focus' => 'opacity: {{SIZE}};',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'input_shadow_focus',
						'label' => __( 'Box Shadow', 'deep' ),
						'selector' => '#wrap {{WRAPPER}} .wn-sb-hole input:focus',
					]
			);
	
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'input_border_focus',
					'label' => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole input:focus',
				]
			);
	
			$this->add_control(
				'input_border_radius_focus', 
				[
					'label' 		=> __( 'Border Radius', 'deep' ), 
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_control(
				'input_padding_focus', 
				[
					'label' 		=> __( 'Padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input:focus' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			
			$this->add_control(
				'input_margin_focus', 
				[
					'label' 		=> __( 'Margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input:focus' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->end_controls_tab();
	
			$this->end_controls_tabs();
	
			$this->add_control(
				'input_transition',
				[
					'label' => __( 'Transition', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'transition: all {{SIZE}}s ease;',
					],
					'separator' => 'before',
				]
			);
			
			$this->add_responsive_control(
				'input_position',
				[
					'label' => __( 'Position', 'deep' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => [
						''  => __( 'Default', 'deep' ),
						'relative'  => __( 'Relative', 'deep' ),
						'absolute' => __( 'Absolute', 'deep' ),
						'fixed' => __( 'Fixed', 'deep' ),
						'static' => __( 'Static', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'position: {{VALUE}}',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
			
			$this->add_responsive_control(
				'input_pos_top',
				[
					'label' => __( 'Top', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'top: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'input_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'input_pos_right',
				[
					'label' => __( 'Right', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'right: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'input_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'input_pos_bottom',
				[
					'label' => __( 'Bottom', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'bottom: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'input_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'input_pos_left',
				[
					'label' => __( 'Left', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'left: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'input_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'input_size',
				[
					'label' => __( 'Width & Height', 'deep' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => [
						'auto'  => __( 'Auto', 'deep' ),
						'100%'  => __( 'Full-Width(100%)', 'deep' ),
						'custom'  => __( 'Custom', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'width: {{VALUE}}',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
			
			$this->add_responsive_control(
				'input_size_width',
				[
					'label' => __( 'Width', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1920,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'width: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'input_size'      => array( 'custom' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'input_size_max_width',
				[
					'label' => __( 'Max Width', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1920,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'max-width: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'input_size'      => array( 'custom' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'input_size_height',
				[
					'label' => __( 'Height', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 500,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'height: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'input_size'      => array( 'custom' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'input_size_max_height',
				[
					'label' => __( 'Max Height', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 500,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole input' => 'max-height: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'input_size'      => array( 'custom' ),
					),
				]
			);
	
			$this->end_controls_section();
	
			$this->start_controls_section(
				'section_button_style',
				[
					'label' => __( 'Button', 'deep' ),
					'tab' => Controls_Manager::TAB_STYLE,
				]
			);
	
			$this->add_responsive_control(
				'button_text_align',
				[
					'label'     => __( 'Text align', 'deep' ),
					'type'      => \Elementor\Controls_Manager::CHOOSE,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'options'   => [
						'left'   => [
							'title' => __( 'Left', 'deep' ),
							'icon'  => 'fa fa-align-left',
						],
						'center' => [
							'title' => __( 'Center', 'deep' ),
							'icon'  => 'fa fa-align-center',
						],
						'right'  => [
							'title' => __( 'Right', 'deep' ),
							'icon'  => 'fa fa-align-right',
						],
					],				
					'toggle'    => true,
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'text-align: {{VALUE}}',
					],
				]
			);
	
			$this->add_responsive_control(
				'button_float',
				[
					'label'     => __( 'Float', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,		
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'right'      => __( 'Right', 'deep' ),
						'left'       => __( 'Left', 'deep' ),
						'unset' => __( 'Unset', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'float: {{VALUE}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
	
			$this->add_responsive_control(
				'button_display',
				[
					'label'     => __( 'Display', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,	
					'devices' => [ 'desktop', 'tablet', 'mobile' ],	
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'inherit'      => __( 'Inherit', 'deep' ),
						'inline'       => __( 'inline', 'deep' ),
						'inline-block' => __( 'inline block', 'deep' ),
						'block'        => __( 'block', 'deep' ),
						'none'         => __( 'none', 'deep' ),
					],	
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'display: {{VALUE}};',
					],
				]
			);
	
			$this->start_controls_tabs(
				'wn_subscribe_style_button_tabs'
			);
	
			$this->start_controls_tab(
				'style_button_normal_tab',
				[
					'label' => __( 'Normal', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'button_typography',
					'label' 	=> __( 'Button Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} .wn-sb-hole .button',
				]
			);
			
			$this->add_control(
				'button_color', 
				[
					'label' 		=> __( 'Button color', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::COLOR,
					'selectors' 	=> [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' => 'button_solid',
					'label' => __( 'Background', 'deep' ),
					'types' => [ 'classic', 'gradient' ],
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole .button',
				]
			);
	
			$this->add_responsive_control(
				'button_opacity',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'opacity: {{SIZE}};',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'button_shadow',
						'label' => __( 'Box Shadow', 'deep' ),
						'selector' => '#wrap {{WRAPPER}} .wn-sb-hole .button',
					]
			);
	
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'button_border',
					'label' => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole .button',
				]
			);
	
			$this->add_responsive_control(
				'button_border_radius', 
				[
					'label' 		=> __( 'Border Radius', 'deep' ), 
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ], 
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'button_padding', 
				[
					'label' 		=> __( 'Button padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'button_margin', 
				[
					'label' 		=> __( 'Button margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);	
	
			$this->end_controls_tab();
	
			$this->start_controls_tab(
				'style_button_hover_tab',
				[
					'label' => __( 'Hover', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'button_typography_hover',
					'label' 	=> __( 'Button Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} .wn-sb-hole .button:hover',
				]
			);
	
			$this->add_control(
				'button_color_hover', 
				[
					'label' 		=> __( 'Button color', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::COLOR,
					'selectors' 	=> [
						'#wrap {{WRAPPER}} .wn-sb-hole .button:hover' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' => 'button_solid_hover',
					'label' => __( 'Background', 'deep' ),
					'types' => [ 'classic' , 'gradient' ],
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole .button:hover',
				]
			);	
	
			$this->add_responsive_control(
				'button_opacity_hover',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button:hover' => 'opacity: {{SIZE}};',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'button_shadow_hover',
						'label' => __( 'Box Shadow', 'deep' ),
						'selector' => '#wrap {{WRAPPER}} .wn-sb-hole .button:hover',
					]
			);
	
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'button_border_hover',
					'label' => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole .button:hover',
				]
			);
	
			$this->add_responsive_control(
				'button_border_radius_hover', 
				[
					'label' 		=> __( 'Border Radius', 'deep' ), 
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ], 
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'button_padding_hover', 
				[
					'label' 		=> __( 'Button padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'button_margin_hover', 
				[
					'label' 		=> __( 'Button margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->end_controls_tab();
			$this->end_controls_tabs();
	
			$this->add_control(
				'button_transition',
				[
					'label' => __( 'Transition', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'transition: all {{SIZE}}s ease;',
					],
					'separator' => 'before',
				]
			);
			
			$this->add_responsive_control(
				'button_position',
				[
					'label' => __( 'Position', 'deep' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => [
						''  => __( 'Default', 'deep' ),
						'relative'  => __( 'Relative', 'deep' ),
						'absolute' => __( 'Absolute', 'deep' ),
						'fixed' => __( 'Fixed', 'deep' ),
						'static' => __( 'Static', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'position: {{VALUE}}',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
			
			$this->add_responsive_control(
				'button_pos_top',
				[
					'label' => __( 'Top', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'top: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'button_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'button_pos_right',
				[
					'label' => __( 'Right', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'right: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'button_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'button_pos_bottom',
				[
					'label' => __( 'Bottom', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'bottom: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'button_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'button_pos_left',
				[
					'label' => __( 'Left', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole .button' => 'left: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'button_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->end_controls_section();
	
			$this->start_controls_section(
				'section_box_style',
				[
					'label' => __( 'Box Style', 'deep' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				]
			);			
	
			$this->add_responsive_control(
				'box_display',
				[
					'label'     => __( 'Display', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,		
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'inherit'      => __( 'Inherit', 'deep' ),
						'inline'       => __( 'inline', 'deep' ),
						'inline-block' => __( 'inline block', 'deep' ),
						'block'        => __( 'block', 'deep' ),
						'none'         => __( 'none', 'deep' ),
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],	
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole' => 'display: {{VALUE}};',
					],
				]
			);
	
			$this->add_control(
				'box_overflow ',
				[
					'label'     => __( 'Overflow', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,		
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'inherit'   => __( 'inherit', 'deep' ),
						'scroll'    => __( 'scroll', 'deep' ),
						'hidden'    => __( 'hidden', 'deep' ),
						'auto' 		=> __( 'auto', 'deep' ),
						'auto'      => __( 'auto', 'deep' ),
						'visible'   => __( 'visible', 'deep' ),
					],	
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole' => 'overflow: {{VALUE}};',
					],
				]
			);
	
			$this->start_controls_tabs(
				'wn_subscribe_box_style_tabs'
			);
	
			$this->start_controls_tab(
				'style_subscribe_box_normal_tab',
				[
					'label' => __( 'Normal', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name'     => 'box_solid',
					'label'    => __( 'Background', 'deep' ),
					'types'    => [ 'classic' , 'gradient' ],
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole',
				]
			);
			
			$this->add_responsive_control(
				'box_opacity',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole' => 'opacity: {{SIZE}};',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name'     => 'box_border',
					'label'    => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole',
				]
			);
	
			$this->add_control(
				'box_border_radius',
				[
					'label' 		=> __( 'Border Radius', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units'    => [ 'px', 'em', '%' ],
					'selectors'     => [
						'#wrap {{WRAPPER}} .wn-sb-hole' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);		
	
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
					[
						'name'     => 'box_shadow',
						'label'    => __( 'Box Shadow', 'deep' ),
						'selector' => '#wrap {{WRAPPER}} .wn-sb-hole',
					]
			);
	
			$this->add_responsive_control(
				'box_padding',
				[
					'label' 		=> __( 'Padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units'    => [ 'px', 'em', '%' ],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors'     => [
						'#wrap {{WRAPPER}} .wn-sb-hole' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'box_margin',
				[
					'label' 		=> __( 'Margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units'    => [ 'px', 'em', '%' ],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors'     => [
						'#wrap {{WRAPPER}} .wn-sb-hole' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->end_controls_tab();
	
			$this->start_controls_tab(
				'style_subscribe_box_hover_tab',
				[
					'label' => __( 'Hover', 'deep' ),
				]
			);
			
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name'     => 'box_solid_hover',
					'label'    => __( 'Background', 'deep' ),
					'types'    => [ 'classic' , 'gradient' ],
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole:hover',
				]
			);
	
			$this->add_responsive_control(
				'box_opacity_hover',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover' => 'opacity: {{SIZE}};',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name'     => 'box_border_hover',
					'label'    => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-sb-hole:hover',
				]
			);
	
			$this->add_control(
				'box_border_radius_hover',
				[
					'label' 		=> __( 'Border Radius', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units'    => [ 'px', 'em', '%' ],
					'selectors'     => [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);		
	
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
					[
						'name'     => 'box_shadow_hover',
						'label'    => __( 'Box Shadow', 'deep' ),
						'selector' => '#wrap {{WRAPPER}} .wn-sb-hole:hover',
					]
			);
	
			$this->add_responsive_control(
				'box_padding_hover',
				[
					'label' 		=> __( 'Padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'size_units'    => [ 'px', 'em', '%' ],
					'selectors'     => [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'box_margin_hover',
				[
					'label' 	  => __( 'Margin', 'deep' ),
					'type' 		  => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units'  => [ 'px', 'em', '%' ],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors'   => [
						'#wrap {{WRAPPER}} .wn-sb-hole:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->end_controls_tab();
			$this->end_controls_tabs();
	
			$this->add_control(
				'main_subscribe_box_transition',
				[
					'label' => __( 'Transition', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-sb-hole' => 'transition: all {{SIZE}}s ease !important;',
					],
					'separator' => 'before',
				]
			);
	
			$this->end_controls_section();
	
		// Custom css tab
		$this->start_controls_section(
			'custom_css_section',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'custom_css',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'type' => \Elementor\Controls_Manager::CODE,
				'language' => 'css',
				'rows' => 20,
				'show_label' => true,
			]
		);

		$this->end_controls_section();		

	}

	/**
	 * Render Tooltip widget output on the frontend.
	 *
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings       = $this->get_settings_for_display();
		$shortcodeclass = $settings['shortcodeclass'] ? $settings['shortcodeclass'] : '';
		$shortcodeid	= $settings['shortcodeid'] ? ' id="' . $settings['shortcodeid'] . '"' : '';

		ob_start();

		$title			= ( $settings['box_title'] ) ? '<h3>'.$settings['box_title'].'</h3>' : '' ;
		$email_name		= ( $settings['service'] == 'FeedBurner' ) ? 'email' : 'MERGE0' ;
		$text			= ( $settings['box_text'] ) ? '<div class="subscribe-box-text"><p>' . $settings['box_text'] . '</p></div>' : '' ;
		$inputtext		= ( $settings['input_text'] ) ? $settings['input_text'] : 'YOUR E-MAIL' ;
		$input			= '
			<div class="subscribe-box-input ' . $shortcodeclass . '"  ' . $shortcodeid . '>
				<input placeholder=" '. $inputtext .'" class="subscribe-box-email" type="email" name="'.$email_name.'" required>
				<button class="subscribe-box-submit button medium" type="submit">
					<span>'. esc_html__('SUBSCRIBE','deep').'</span>
				</button>
			</div>';

		if ($settings['type'] == 'boxed'){
			echo '
				<div class="wn-sb-hole subscribe-box ' . $shortcodeclass . '"  ' . $shortcodeid . '>
					<div class="subscribe-box-top">
						<i class="ti-rss"></i>' . $title . '
					</div>';
		} else {
			echo '<div class="wn-sb-hole subscribe-'.$settings['type'].' ' . $shortcodeclass . '"  ' . $shortcodeid . '>' . $title;
		}
		?>
		<?php if ($settings['service'] == 'feedburner') { ?>
			<form class="subscribe-box-form" action="http://feedburner.google.com/fb/a/mailverify" method="post" target="popupwindow" onSubmit="window.open('http://feedburner.google.com/fb/a/mailverify?uri=<?php echo esc_url( $settings['feedburner_id'] ); ?>', 'popupwindow', 'scrollbars=yes,width=550,height=520');return true">
				<input type="hidden" value="<?php echo esc_attr($settings['feedburner_id']); ?>" name="uri"/>
				<input type="hidden" name="loc" value="en_US"/>
		<?php } elseif($settings['service'] == 'mailchimp'){ ?>
			<form action="<?php echo esc_url($settings['mailchimp_url']); ?>" method="post" id="mc-embedded-subscribe-form" name="mc-embedded-subscribe-form">
		<?php } ?>

		<?php if($settings['type'] == 'bar1'){
			if($text){
				echo '<div class="container ' . $shortcodeclass . '"  ' . $shortcodeid . '><div class="col-md-6">' . $text . '</div><div class="col-md-6">' .$input . '</div></div>';
			}else{
				echo '' . $input;
			}
		}else{
			echo '' . $text.$input;
		}?>
			</form>
		</div>


	<?php
		$out = ob_get_contents();
		ob_end_clean();

		$custom_css = $settings['custom_css'];

		if ( $custom_css != '' ) {
			echo '<style>'. $custom_css .'</style>';
		}
		
		echo $out;

	}

}
