<?php
namespace Elementor;
class Webnus_Element_Widgets_Tabs extends \Elementor\Widget_Base {

	/**
	 * Retrieve Single Cause widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {

		return 'Tabs';
		
	}

	/**
	 * Retrieve Single Cause widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {

		return esc_html__( 'Webnus Tab Content', 'deep' );

	}

	/**
	 * Retrieve Single Cause widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {

		return 'ti-layout-tab';

	}

	/**
	 * Set widget category.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget category.
	 */
	public function get_categories() {

		return [ 'webnus' ];

	}

	public function get_style_depends() {

		return [ 'wn-deep-tab-content' ];
		
	}

	public function get_script_depends() {

		return [ 'tab-content' ];
		
	}

	/**
	 * Register Single Cause widget controls.
	 *
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

        $tabstpls = Plugin::instance()->templates_manager->get_source( 'local' )->get_items();        
		$tabstpls_opts = [
			'0' => __( 'Elementor template is not defined yet.', 'deep' )
		];

		if ( ! empty( $tabstpls ) ) {
			$tabstpls_opts = [
				'0' => __( 'Select elementor template', 'deep' )
			];
			foreach ( $tabstpls as $template ) {
				$tabstpls_opts[$template['template_id']] = $template['title'] . ' (' . $template['type'] . ')';
			}
		}

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Tabs', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
		);				
		$repeater = new Repeater();
		$repeater->add_control(
			'tab_item',
			[
				'label'			=> __( 'Choose template', 'deep' ),
				'type'			=> Controls_Manager::SELECT,
				'default'		=> '0',
				'options'		=> $tabstpls_opts,
				'label_block'	=> 'true',
			]
		);	
		$repeater->add_control(
			'tab_title',
			[
				'label'			=> __( 'Title', 'deep' ),
				'type'			=> Controls_Manager::TEXT,
				'default'		=> __( 'Tab title' , 'deep' ),
				'label_block'	=> true,
			]
		);		
		$repeater->add_control(
			'iconname',
			[
				'label' => __( 'Tab Icon', 'deep' ),
				'type' => \Elementor\Controls_Manager::ICON,
				'default' => 'li_star',
			]
		);
		$this->add_control(
			'tabs',
			[
				'label'		=> __( 'Repeater List', 'deep' ),
				'type'		=> Controls_Manager::REPEATER,
				'fields'	=> $repeater->get_controls(),
				'default'	=> [
					[						
						'tab_title'	=> __( 'Tab 1', 'deep' ),
						'iconname'	=> __( 'li_star' ),
					],
					[					
						'tab_title'	=> __( 'Tab 2', 'deep' ),
						'iconname'	=> __( 'li_star' ),
					],					

				],
				'title_field' => '{{{ tab_title }}}',
			]
		);
        $this->end_controls_section();		

	// Style
	$this->start_controls_section(
		'section_title_style',
		[
			'label' => __( 'Title', 'deep' ),
			'tab' => Controls_Manager::TAB_STYLE,
		]
	);

	$this->add_control(
		'title_text_align',
		[
			'label'     => __( 'Text align', 'deep' ),
			'type'      => \Elementor\Controls_Manager::CHOOSE,
			'options'   => [
				'left'   => [
					'title' => __( 'Left', 'deep' ),
					'icon'  => 'fa fa-align-left',
				],
				'center' => [
					'title' => __( 'Center', 'deep' ),
					'icon'  => 'fa fa-align-center',
				],
				'right'  => [
					'title' => __( 'Right', 'deep' ),
					'icon'  => 'fa fa-align-right',
				],
			],				
			'toggle'    => true,
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li' => 'text-align: {{VALUE}}',
			],
		]
	);

	$this->add_responsive_control(
		'title_float',
		[
			'label'     => __( 'Float', 'deep' ), 
			'type'      => \Elementor\Controls_Manager::SELECT,		
			'options'   => [ 
				''      => __( 'Default', 'deep' ),
				'right'      => __( 'Right', 'deep' ),
				'left'       => __( 'Left', 'deep' ),
				'unset' => __( 'Unset', 'deep' ),
			],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li' => 'float: {{VALUE}};',
			],
			'devices' => [ 'desktop', 'tablet', 'mobile' ],
		]
	);

	$this->add_control(
		'title_display',
		[
			'label'     => __( 'Display', 'deep' ), 
			'type'      => \Elementor\Controls_Manager::SELECT,		
			'options'   => [ 
				'inherit'      => __( 'Inherit', 'deep' ),
				'inline'       => __( 'inline', 'deep' ),
				'inline-block' => __( 'inline block', 'deep' ),
				'block'        => __( 'block', 'deep' ),
				'none'         => __( 'none', 'deep' ),
			],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li' => 'display: {{VALUE}};',
			],
		]
	);

	$this->start_controls_tabs(
		'title_style_tabs'
	);

	$this->start_controls_tab(
		'style_title_normal_tab',
		[
			'label' => __( 'Normal', 'deep' ),
		]
	);

	$this->add_group_control(
		Group_Control_Typography::get_type(),
		[
			'name' 		=> 'title_typography',
			'label' 	=> __( 'Typography', 'deep' ),
			'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
			'selector' 	=> '#wrap {{WRAPPER}} .deep-tab-content .tab-menu li',
		]
	);

	$this->add_control(
		'title_color', 
		[
			'label' 		=> __( 'Color', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::COLOR,
			'selectors' 	=> [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li' => 'color: {{VALUE}}',
			],
		]
	);

	$this->add_group_control(
		Group_Control_Background::get_type(),
		[
			'name' => 'title_bg',
			'label' => __( 'Background', 'deep' ),
			'types' => [ 'classic' ],
			'selector' => '#wrap {{WRAPPER}} .deep-tab-content .tab-menu li',
		]
	);
		
	$this->add_control(
		'title_opacity',
		[
			'label' => __( 'Opacity', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1,
					'step' => 0.1,
				],
			],			
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li' => 'opacity: {{SIZE}};',
			],
		]
	);

	$this->add_group_control(
		Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'title_box_shadow',
				'label'    => __( 'Box Shadow', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .deep-tab-content .tab-menu li',
			]
	);
	
	$this->add_group_control(
		Group_Control_Border::get_type(),
		[
			'name' => 'title_border',
			'label' => __( 'Border', 'deep' ),
			'selector' => '#wrap {{WRAPPER}} .deep-tab-content .tab-menu li',
		]
	);

	$this->add_control(
		'title_border_radius', 
		[
			'label' 		=> __( 'Border Radius', 'deep' ), 
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'title_padding', 
		[
			'label' 		=> __( 'Padding', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'title_margin', 
		[
			'label' 		=> __( 'Margin', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->end_controls_tab();

	$this->start_controls_tab(
		'style_title_hover_tab',
		[
			'label' => __( 'Hover', 'deep' ),
		]
	);

	$this->add_group_control(
		Group_Control_Typography::get_type(),
		[
			'name' 		=> 'title_typography_hover',
			'label' 	=> __( 'Typography', 'deep' ),
			'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
			'selector' 	=> '#wrap {{WRAPPER}} .deep-tab-content .tab-menu li:hover',
		]
	);

	$this->add_control(
		'title_color_hover', 
		[
			'label' 		=> __( 'Color', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::COLOR,
			'selectors' 	=> [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li:hover' => 'color: {{VALUE}}',
			],
		]
	);

	$this->add_group_control(
		Group_Control_Background::get_type(),
		[
			'name' => 'title_bg_hover',
			'label' => __( 'Background', 'deep' ),
			'types' => [ 'classic' ],
			'selector' => '#wrap {{WRAPPER}} .deep-tab-content .tab-menu li:hover',
		]
	);

	$this->add_control(
		'title_opacity_hover',
		[
			'label' => __( 'Opacity', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1,
					'step' => 0.1,
				],
			],			
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li:hover' => 'opacity: {{SIZE}};',
			],
		]
	);

	$this->add_group_control(
		Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'title_box_shadow_hover',
				'label'    => __( 'Box Shadow', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .deep-tab-content .tab-menu li:hover',
			]
	);

	$this->add_group_control(
		Group_Control_Border::get_type(),
		[
			'name' => 'title_border_hover',
			'label' => __( 'Border', 'deep' ),
			'selector' => '#wrap {{WRAPPER}} .deep-tab-content .tab-menu li:hover',
		]
	);

	$this->add_control(
		'title_border_radius_hover', 
		[
			'label' 		=> __( 'Border Radius', 'deep' ), 
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'title_padding_hover', 
		[
			'label' 		=> __( 'Padding', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'title_margin_hover', 
		[
			'label' 		=> __( 'Margin', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);	

	$this->end_controls_tab();
	$this->end_controls_tabs();

	$this->add_control(
		'title_transition',
		[
			'label' => __( 'Transition', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu li' => 'transition: all {{SIZE}}s ease;',
			],
			'separator' => 'before',
		]
	);

	$this->end_controls_section();

	$this->start_controls_section(
		'section_icon_style',
		[
			'label' => __( 'Icon', 'deep' ),
			'tab' => Controls_Manager::TAB_STYLE,
		]
	);

	$this->add_control(
		'icon_text_align',
		[
			'label'     => __( 'Text align', 'deep' ),
			'type'      => \Elementor\Controls_Manager::CHOOSE,
			'options'   => [
				'left'   => [
					'title' => __( 'Left', 'deep' ),
					'icon'  => 'fa fa-align-left',
				],
				'center' => [
					'title' => __( 'Center', 'deep' ),
					'icon'  => 'fa fa-align-center',
				],
				'right'  => [
					'title' => __( 'Right', 'deep' ),
					'icon'  => 'fa fa-align-right',
				],
			],				
			'toggle'    => true,
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu i' => 'text-align: {{VALUE}}',
			],
		]
	);

	$this->add_responsive_control(
		'icon_float',
		[
			'label'     => __( 'Float', 'deep' ), 
			'type'      => \Elementor\Controls_Manager::SELECT,		
			'options'   => [ 
				''      => __( 'Default', 'deep' ),
				'right'      => __( 'Right', 'deep' ),
				'left'       => __( 'Left', 'deep' ),
				'unset' => __( 'Unset', 'deep' ),
			],
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu i' => 'float: {{VALUE}};',
			],
			'devices' => [ 'desktop', 'tablet', 'mobile' ],
		]
	);

	$this->add_control(
		'icon_display',
		[
			'label'     => __( 'Display', 'deep' ), 
			'type'      => \Elementor\Controls_Manager::SELECT,		
			'options'   => [ 
				'inherit'      => __( 'Inherit', 'deep' ),
				'inline'       => __( 'inline', 'deep' ),
				'inline-block' => __( 'inline block', 'deep' ),
				'block'        => __( 'block', 'deep' ),
				'none'         => __( 'none', 'deep' ),
			],
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu i' => 'display: {{VALUE}};',
			],
		]
	);

	$this->start_controls_tabs(
		'icon_style_tabs'
	);

	$this->start_controls_tab(
		'style_icon_normal_tab',
		[
			'label' => __( 'Normal', 'deep' ),
		]
	);

	$this->add_control(
		'icon_size',
		[
			'label' => __( 'Icon Size', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 200,
					'step' => 1,
				],
				'%' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'default' => [
				'unit' => 'px',
				'size' => 18,
			],
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu i' => 'font-size: {{SIZE}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'icon_color', 
		[
			'label' 		=> __( 'Color', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::COLOR,
			'selectors' 	=> [
				'{{WRAPPER}} .deep-tab-content .tab-menu i' => 'color: {{VALUE}}',
			],
		]
	);

	$this->add_group_control(
		Group_Control_Background::get_type(),
		[
			'name' => 'icon_bg',
			'label' => __( 'Background', 'deep' ),
			'types' => [ 'classic' ],
			'selector' => '{{WRAPPER}} .deep-tab-content .tab-menu i',
		]
	);
	
	$this->add_control(
		'icon_opacity',
		[
			'label' => __( 'Opacity', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1,
					'step' => 0.1,
				],
			],			
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu i' => 'opacity: {{SIZE}};',
			],
		]
	);

	$this->add_group_control(
		Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'icon_box_shadow',
				'label'    => __( 'Box Shadow', 'deep' ),
				'selector' => '{{WRAPPER}} .deep-tab-content .tab-menu i',
			]
	);
	
	$this->add_group_control(
		Group_Control_Border::get_type(),
		[
			'name' => 'icon_border',
			'label' => __( 'Border', 'deep' ),
			'selector' => '{{WRAPPER}} .deep-tab-content .tab-menu i',
		]
	);

	$this->add_control(
		'icon_border_radius', 
		[
			'label' 		=> __( 'Border Radius', 'deep' ), 
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'icon_padding', 
		[
			'label' 		=> __( 'Padding', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'icon_margin', 
		[
			'label' 		=> __( 'Margin', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);		

	$this->end_controls_tab();

	$this->start_controls_tab(
		'style_icon_hover_tab',
		[
			'label' => __( 'Hover', 'deep' ),
		]
	);

	$this->add_control(
		'icon_size_hover',
		[
			'label' => __( 'Icon Size', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 200,
					'step' => 1,
				],
				'%' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'default' => [
				'unit' => 'px',
				'size' => 18,
			],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu:hover i' => 'font-size: {{SIZE}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'icon_color_hover', 
		[
			'label' 		=> __( 'Color', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::COLOR,
			'selectors' 	=> [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu:hover i' => 'color: {{VALUE}}',
			],
		]
	);

	$this->add_group_control(
		Group_Control_Background::get_type(),
		[
			'name' => 'icon_bg_hover',
			'label' => __( 'Background', 'deep' ),
			'types' => [ 'classic' ],
			'selector' => '#wrap {{WRAPPER}} .deep-tab-content .tab-menu:hover i',
		]
	);

	$this->add_control(
		'icon_opacity_hover',
		[
			'label' => __( 'Opacity', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1,
					'step' => 0.1,
				],
			],			
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu:hover i' => 'opacity: {{SIZE}};',
			],
		]
	);
	
	$this->add_group_control(
		Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'icon_box_shadow_hover',
				'label'    => __( 'Box Shadow', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .deep-tab-content .tab-menu:hover i',
			]
	);

	$this->add_group_control(
		Group_Control_Border::get_type(),
		[
			'name' => 'icon_border_hover',
			'label' => __( 'Border', 'deep' ),
			'selector' => '#wrap {{WRAPPER}} .deep-tab-content .tab-menu:hover i',
		]
	);

	$this->add_control(
		'icon_border_radius_hover', 
		[
			'label' 		=> __( 'Border Radius', 'deep' ), 
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu:hover i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'icon_padding_hover', 
		[
			'label' 		=> __( 'Padding', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu:hover i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'icon_margin_hover', 
		[
			'label' 		=> __( 'Margin', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu:hover i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);	

	$this->end_controls_tab();
	$this->end_controls_tabs();

	$this->add_control(
		'icon_transition',
		[
			'label' => __( 'Transition', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu i' => 'transition: all {{SIZE}}s ease;',
			],
			'separator' => 'before',
		]
	);
	
	$this->end_controls_section();	

	// Active Tab
	$this->start_controls_section(
		'active_tab_style',
		[
			'label' => __( 'Active Tab', 'deep' ),
			'tab' => Controls_Manager::TAB_STYLE,
		]
	);

	$this->add_control(
		'title_active_tab',
		[
			'label'     => __( 'Active Title', 'deep' ),
			'type'      => \Elementor\Controls_Manager::HEADING,
		]
	);

	$this->add_group_control(
		Group_Control_Typography::get_type(),
		[
			'name' 		=> 'title_active_typography',
			'label' 	=> __( 'Typography', 'deep' ),
			'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
			'selector' 	=> '#wrap {{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active',
		]
	);

	$this->add_control(
		'title_active_color', 
		[
			'label' 		=> __( 'Color', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::COLOR,
			'selectors' 	=> [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active' => 'color: {{VALUE}}',
			],
		]
	);

	$this->add_group_control(
		Group_Control_Background::get_type(),
		[
			'name' => 'title_active_bg',
			'label' => __( 'Background', 'deep' ),
			'types' => [ 'classic' ],
			'selector' => '#wrap {{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active',
		]
	);
		
	$this->add_control(
		'title_active_opacity',
		[
			'label' => __( 'Opacity', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1,
					'step' => 0.1,
				],
			],			
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active' => 'opacity: {{SIZE}};',
			],
		]
	);

	$this->add_group_control(
		Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'title_active_box_shadow',
				'label'    => __( 'Box Shadow', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active',
			]
	);
	
	$this->add_group_control(
		Group_Control_Border::get_type(),
		[
			'name' => 'title_active_border',
			'label' => __( 'Border', 'deep' ),
			'selector' => '#wrap {{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active',
		]
	);

	$this->add_control(
		'title_active_border_radius', 
		[
			'label' 		=> __( 'Border Radius', 'deep' ), 
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'title_active_padding', 
		[
			'label' 		=> __( 'Padding', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'title_active_margin', 
		[
			'label' 		=> __( 'Margin', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'icon_active_tab',
		[
			'label'     => __( 'Active Icon', 'deep' ),
			'type'      => \Elementor\Controls_Manager::HEADING,
			'separator' => 'before',
		]
	);

	$this->add_control(
		'icon_active_size',
		[
			'label' => __( 'Icon Size', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 200,
					'step' => 1,
				],
				'%' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active i' => 'font-size: {{SIZE}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'icon_active_color', 
		[
			'label' 		=> __( 'Color', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::COLOR,
			'selectors' 	=> [
				'{{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active i' => 'color: {{VALUE}}',
			],
		]
	);

	$this->add_group_control(
		Group_Control_Background::get_type(),
		[
			'name' => 'icon_active_bg',
			'label' => __( 'Background', 'deep' ),
			'types' => [ 'classic' ],
			'selector' => '{{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active i',
		]
	);
	
	$this->add_control(
		'icon_active_opacity',
		[
			'label' => __( 'Opacity', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1,
					'step' => 0.1,
				],
			],			
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active i' => 'opacity: {{SIZE}};',
			],
		]
	);

	$this->add_group_control(
		Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'icon_active_box_shadow',
				'label'    => __( 'Box Shadow', 'deep' ),
				'selector' => '{{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active i',
			]
	);
	
	$this->add_group_control(
		Group_Control_Border::get_type(),
		[
			'name' => 'icon_active_border',
			'label' => __( 'Border', 'deep' ),
			'selector' => '{{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active i',
		]
	);

	$this->add_control(
		'icon_active_border_radius', 
		[
			'label' 		=> __( 'Border Radius', 'deep' ), 
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'icon_active_padding', 
		[
			'label' 		=> __( 'Padding', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'icon_active_margin', 
		[
			'label' 		=> __( 'Margin', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu .tab-link.active i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);		

	$this->add_control(
		'active_icon_title_transition',
		[
			'label' => __( 'Transition', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'selectors' => [
				'{{WRAPPER}} .deep-tab-content .tab-menu .tab-link i, #wrap {{WRAPPER}} .deep-tab-content .tab-menu .tab-link li' => 'transition: all {{SIZE}}s ease;',
			],
			'separator' => 'before',
		]
	);
	
	$this->end_controls_section();

	$this->start_controls_section(
		'box_style',
		[
			'label' => __( 'Box Style', 'deep' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		]
	);

	$this->add_control(
		'box_display',
		[
			'label'     => __( 'Display', 'deep' ), 
			'type'      => \Elementor\Controls_Manager::SELECT,		
			'options'   => [ 
				''      => __( 'Default', 'deep' ),
				'inherit'      => __( 'Inherit', 'deep' ),
				'inline'       => __( 'inline', 'deep' ),
				'inline-block' => __( 'inline block', 'deep' ),
				'block'        => __( 'block', 'deep' ),
				'none'         => __( 'none', 'deep' ),
			],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content' => 'display: {{VALUE}};',
			],
		]
	);

	$this->add_control(
		'box_overflow ',
		[
			'label'     => __( 'Overflow', 'deep' ), 
			'type'      => \Elementor\Controls_Manager::SELECT,		
			'options'   => [ 
				''      => __( 'Default', 'deep' ),
				'inherit'   => __( 'inherit', 'deep' ),
				'scroll'    => __( 'scroll', 'deep' ),
				'hidden'    => __( 'hidden', 'deep' ),
				'auto' 		=> __( 'auto', 'deep' ),
				'visible'   => __( 'visible', 'deep' ),
			],
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content' => 'overflow: {{VALUE}};',
			],
		]
	);

	$this->start_controls_tabs(
		'box_style_tabs'
	);

	$this->start_controls_tab(
		'style_box_normal_tab',
		[
			'label' => __( 'Normal', 'deep' ),
		]
	);

	
	$this->add_group_control(
		Group_Control_Background::get_type(),
		[
			'name'     => 'box_bg',
			'label'    => __( 'Background', 'deep' ),
			'types'    => [ 'classic' , 'gradient' ],
			'selector' => '#wrap {{WRAPPER}} .deep-tab-content',
		]
	);

	$this->add_group_control(
		Group_Control_Border::get_type(),
		[
			'name'     => 'box_border',
			'label'    => __( 'Border', 'deep' ),
			'selector' => '#wrap {{WRAPPER}} .deep-tab-content',
		]
	);
	$this->add_control(
		'box_border_radius',
		[
			'label' 		=> __( 'Border Radius', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'    => [ 'px', 'em', '%' ],
			'selectors'     => [
				'#wrap {{WRAPPER}} .deep-tab-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);		
	$this->add_group_control(
		Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'box_shadow',
				'label'    => __( 'Box Shadow', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .deep-tab-content',
			]
	);

	$this->add_control(
		'box_opacity',
		[
			'label' => __( 'Opacity', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1,
					'step' => 0.1,
				],
			],			
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content' => 'opacity: {{SIZE}};',
			],
		]
	);


	$this->add_control(
		'box_padding',
		[
			'label' 		=> __( 'Padding', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'    => [ 'px', 'em', '%' ],
			'selectors'     => [
				'#wrap {{WRAPPER}} .deep-tab-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);
	$this->add_control(
		'box_margin',
		[
			'label' 		=> __( 'Margin', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'    => [ 'px', 'em', '%' ],
			'selectors'     => [
				'#wrap {{WRAPPER}} .deep-tab-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->end_controls_tab();

	$this->start_controls_tab(
		'style_box_hover_tab',
		[
			'label' => __( 'Hover', 'deep' ),
		]
	);

	$this->add_group_control(
		Group_Control_Background::get_type(),
		[
			'name'     => 'box_bg_hover',
			'label'    => __( 'Background', 'deep' ),
			'types'    => [ 'classic' , 'gradient' ],
			'selector' => '#wrap {{WRAPPER}} .deep-tab-content:hover',
		]
	);

	$this->add_group_control(
		Group_Control_Border::get_type(),
		[
			'name'     => 'box_border_hover',
			'label'    => __( 'Border', 'deep' ),
			'selector' => '#wrap {{WRAPPER}} .deep-tab-content:hover',
		]
	);

	$this->add_control(
		'box_border_radius_hover',
		[
			'label' 		=> __( 'Border Radius', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'    => [ 'px', 'em', '%' ],
			'selectors'     => [
				'#wrap {{WRAPPER}} .deep-tab-content:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);			

	$this->add_group_control(
		Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'box_shadow_hover',
				'label'    => __( 'Box Shadow', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .deep-tab-content:hover',
			]
	);

	$this->add_control(
		'box_opacity_hover',
		[
			'label' => __( 'Opacity', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1,
					'step' => 0.1,
				],
			],			
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content:hover' => 'opacity: {{SIZE}};',
			],
		]
	);

	$this->add_control(
		'box_padding_hover',
		[
			'label' 		=> __( 'Padding', 'deep' ),
			'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'    => [ 'px', 'em', '%' ],
			'selectors'     => [
				'#wrap {{WRAPPER}} .deep-tab-content:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->add_control(
		'box_margin_hover',
		[
			'label' 	  => __( 'Margin', 'deep' ),
			'type' 		  => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units'  => [ 'px', 'em', '%' ],
			'selectors'   => [
				'#wrap {{WRAPPER}} .deep-tab-content:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$this->end_controls_tab();
	$this->end_controls_tabs();

	$this->add_control(
		'box_transition',
		[
			'label' => __( 'Transition', 'deep' ),
			'type' => Controls_Manager::SLIDER,
			'selectors' => [
				'#wrap {{WRAPPER}} .deep-tab-content' => 'transition: all {{SIZE}}s ease;',
			],
			'separator' => 'before',
		]
	);

	$this->end_controls_section();	

		// Custom css tab
		$this->start_controls_section(
			'custom_css_section',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'custom_css',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'type' => \Elementor\Controls_Manager::CODE,
				'language' => 'css',
				'rows' => 20,
				'show_label' => true,
			]
		);
		$this->end_controls_section();		

	}

	/**
	 * Render Single Cause widget output on the frontend.
	 *
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

        $settings = $this->get_settings();		
                    
		$tabs = $settings['tabs'];  		

        echo '<div class="deep-tab-content">';
            echo '<ul class="tab-menu">';
                foreach ( $tabs as $tab ) {
					echo '<li class="tab-link" data-id="' . sanitize_title( $tab['tab_title'] ) . '">';		
					echo '<i class="' . esc_attr($tab['iconname']) . '"></i>';
					echo $tab['tab_title'];
					echo '</li>'; 
                }
            echo '</ul>';

            foreach ( $tabs as $tab ) {
                echo '
                <div id="' . sanitize_title( $tab['tab_title'] ) . '" class="tab-content">
                    ' . Plugin::instance()->frontend->get_builder_content_for_display( $tab['tab_item'] ) . '    
				</div>';			
            }
        echo '</div>';
					
		$custom_css = $settings['custom_css'];

		if ( $custom_css != '' ) {

			deep_save_dyn_styles( $custom_css );

			if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
				echo '<style>'. $custom_css .'</style>';
			}

		}
		
	}

}