<?php
class DeepWPBakeryInstagram extends DeepWPBakery {
	
	/**
	 * Instance of this class.
	 *
	 * @since   1.0.0
	 * @access  public
	 * @var     DeepWPBakeryInstagram
	 */
	public static $instance;

	private $type;

	/**
	 * Provides access to a single instance of a module using the singleton pattern.
	 *
	 * @since   1.0.0
	 * @return  object
	 */
	public static function get_instance() {
		if ( self::$instance === null ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	/**
	 * Define the core functionality of the theme.
	 *
	 * Load the dependencies.
	 *
	 * @since   1.0.0
	 */
	public function __construct() {
		add_shortcode( 'deep-instagram', array( $this, 'output' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ) );			
		add_action( 'wp_head', function() {
			echo '<script>var deep_instagram_styles = {}; </script>';
		});
	}

	/**
	 * Shortcode Output.
	 *
	 *
	 * @since   1.0.0
	 */
	public function output( $atts, $content = null ) {		
		extract(shortcode_atts(array(
			'type'				 => 'default',				
			'token'			     => '',
			'insta_post_number'	 => '',	
			'shortcodeclass' 	 => '',
			'shortcodeid' 	 	 => '',
		), $atts));

		wp_enqueue_style( 'wn-deep-instagram', DEEP_ASSETS_URL . 'css/frontend/instagram/instagram.css' );		
		add_action( 'wp_footer', function() {
			echo '<script>
			var element = document.getElementById("instagram.css");
			if(element && !deep_instagram_styles["wn-deep-instagram-css"]) {
				deep_instagram_styles["wn-deep-instagram-css"] = true;
				var wrap = document.createElement("div");
				wrap.appendChild(element.cloneNode(true));
				document.getElementsByTagName("head")[0].innerHTML = document.getElementsByTagName("head")[0].innerHTML + wrap.innerHTML;
				if(element.parentNode) {
					element.parentNode.removeChild(element);
				} else {
					element.remove(element);
				}
			}
			</script>';	
		}, 100);

		$shortcodeclass 	= $shortcodeclass ? $shortcodeclass : '';
		$shortcodeid		= $shortcodeid ? ' id="' . $shortcodeid . '"' : '';

		if ( empty( $type ) ) $type = 'default';		
		$limit				= !empty($insta_post_number) ? $insta_post_number : '9';
		
		$image_count = 0;

		if ( $token ) {
			$img_data = deep_theme_instagram($token);
			$images = json_decode($img_data['body']);	
			?>

			<div class="instagram-feed <?php echo esc_attr( $type ); ?>  <?php echo esc_attr( $shortcodeclass ); ?>" <?php echo esc_attr( $shortcodeid ); ?>>
				<div class="instagram-wrap">				
				<?php

				switch ( $type ) :
					case 'default':	
						echo '<ul>';
						foreach($images->data as $content) {
							$image_count++;																														
							
							echo '<li><a href="'. esc_url( $content->permalink ) .'"><img src="' . esc_url( $content->media_url ) .'"/></a></li>';																						

							if ( $image_count >= $limit) {
								break;
							}
								
						}
						echo '</ul>';
						
					break;

					case 'carousel':																															
						echo '<div class="owl-carousel-instagram owl-carousel owl-theme">';							
							foreach($images->data as $content) {
								$image_count++;																														
								$username = $content->username;
								echo '<li><a href="'. esc_url( $content->permalink ) .'"><img src="' . esc_url( $content->media_url ) .'"/></a></li>';																						

								if ( $image_count >= $limit) {
									break;
								}
									
							}																
						echo '</div>';																						
						echo '<div class="instagram-text"><i class="wn-fab wn-fa-instagram"></i> Follow us <a href="http://instagram.com/' . $username . '">@' . $username .  '</a></div>';									
					break;

					case 'grid':	
						echo '<ul>';							
						foreach($images->data as $content) {
							$image_count++;																														
							
							echo '<li><a href="'. esc_url( $content->permalink ) .'"><img src="' . esc_url( $content->media_url ) .'"/></a></li>';																						

							if ( $image_count >= $limit) {
								break;
							}
								
						}
						echo '</ul>';										
					break;

				endswitch;	
				
				?>

					<div class="clear"></div>
				</div>
			</div>

			<?php
		
		}
	}
	
	/**
	 * Required scripts.
	 *
	 * @since   1.0.0
	 */
	public function scripts() {
		if ( self::used_shortcode_in_page( 'Instagram' ) ) {			
			wp_enqueue_style( 'wn-deep-Instagram', DEEP_ASSETS_URL . 'css/frontend/Instagram/Instagram.css' );				
		}
	}

} DeepWPBakeryInstagram::get_instance(); ?>