<?php
class DeepWPBakerySermonCategory extends DeepWPBakery {

	/**
	 * Instance of this class.
	 *
	 * @since   1.0.0
	 * @access  public
	 * @var     DeepWPBakerySermonCategory
	 */
	public static $instance;

	private $type;

	/**
	 * Provides access to a single instance of a module using the singleton pattern.
	 *
	 * @since   1.0.0
	 * @return  object
	 */
	public static function get_instance() {
		if ( self::$instance === null ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	/**
	 * Define the core functionality of the theme.
	 *
	 * Load the dependencies.
	 *
	 * @since   1.0.0
	 */
	public function __construct() {
		add_shortcode( 'sermon-category', array( $this, 'output' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ) );
		add_action( 'wp_head', function() {
			echo '<script>var deep_sermon_category_styles = {}; </script>';
		});
	}

	/**
	 * Shortcode Output.
	 *
	 *
	 * @since   1.0.0
	 */
	public function output( $atts, $content = null ) {
        extract(shortcode_atts(array(
            'category'          => '',
            'image'             => '',
            'thumbnail'         => '',
            'shortcodeclass'    => '',
            'shortcodeid' 	    => '',
        ), $atts));

		wp_enqueue_style( 'wn-deep-sermon-category', DEEP_ASSETS_URL . 'css/frontend/sermon-category/sermon-category.css' );
		add_action( 'wp_footer', function() {
			echo '<script>
			var element = document.getElementById("sermon-category.css");
			if(element && !deep_sermon_category_styles["wn-deep-sermon-category-css"]) {
				deep_sermon_category_styles["wn-deep-sermon-category-css"] = true;
				var wrap = document.createElement("div");
				wrap.appendChild(element.cloneNode(true));
				document.getElementsByTagName("head")[0].innerHTML = document.getElementsByTagName("head")[0].innerHTML + wrap.innerHTML;
				if(element.parentNode) {
					element.parentNode.removeChild(element);
				} else {
					element.remove(element);
				}
			}
			</script>';
        }, 100);

        $shortcodeclass 	= $shortcodeclass ? $shortcodeclass : '';
        $shortcodeid		= $shortcodeid ? ' id=' . $shortcodeid . '' : '';
        $category = get_term_by( 'slug', $category, 'sermon_category' );
        $image_url = ($image) ? wp_get_attachment_url($image) : '';
        if( !empty( $thumbnail ) ) {
            if ( !class_exists( 'Wn_Img_Maniuplate' ) ) {
                require_once DEEP_CORE_DIR . 'helper-classes/class_webnus_manuplate.php';
            }
            $patt = array ( '0'  => 'x', '1'  => '*' );
            $arr = explode( chr( 1 ), str_replace( $patt, chr( 1 ), $thumbnail ) );
            $img = new Wn_Img_Maniuplate;
            $image_url = $img->m_image( $image, $image_url , $arr['0'] , $arr['1'] );
        }
        $cat_link = isset( $category ) ? get_category_link( $category ) : '';
        $out = '
            <div class="sermon-category-parent ' . esc_attr( $shortcodeclass ) . '"  ' . esc_attr( $shortcodeid ) . '>
                <a href="' . esc_url( $cat_link )  . '" title="' . esc_attr( sprintf( __( '%s category', 'deep' ), $category->name ) ) . '">
                    <img src="' . esc_url( $image_url ) . '" alt="' . esc_attr( $category->name ) . '">
                    <div class="sermon-overlay colorb"></div>
                    <div class="sermon-category-box">
                        <div class="sermon-category-name">
                            '.esc_html( $category->name ).'
                        </div>
                        <div class="sermon-category-count">
                            '. esc_html( 'sermons' , 'deep' ) . ' ' . '(' . esc_html( $category->count ) . ')' .'
                        </div>
                    </div>
                </a>
            </div>
        ';
        return $out;
	}

	/**
	 * Required scripts.
	 *
	 * @since   1.0.0
	 */
	public function scripts() {
		if ( self::used_shortcode_in_page( 'sermon-category' ) ) {
			wp_enqueue_style( 'wn-deep-sermon-category', DEEP_ASSETS_URL . 'css/frontend/sermon-category/sermon-category.css' );
		}
	}

} DeepWPBakerySermonCategory::get_instance();